/// This enum represents map exhibition language codes.
///
/// The basic naming pattern consists of a
/// 2-letter ISO 639-1 language code followed by a
/// 2-letter ISO 3166-1 country code.
///
/// Some language codes consist only of a language code, i.e. without a country code.
///
/// When there is no ISO 639-1 language code, the related
/// ISO 639-2 or
/// ISO 639-3 language code is used.
///
/// In case the script is specified its
/// ISO 15924 code is used.

enum MapLanguage {
  /// English (United States)
  enUs,

  /// Afrikaans
  afZa,

  /// Albanian
  sqAl,

  /// Amharic (Ethiopia)
  amEt,

  /// Arabic (Saudi Arabia)
  arSa,

  /// Armenian
  hyAm,

  /// Assamese (India)
  asIn,

  /// Azeri - Latin
  azLatnAz,

  /// Bangla (Bangladesh)
  bnBd,

  /// Bangla (India)
  bnIn,

  /// Basque
  euEs,

  /// Belarusian
  beBy,

  /// Bosnian - Latin
  bsLatnBa,

  /// Bulgarian
  bgBg,

  /// Catalan (Spain)
  caEs,

  /// Central Kurdish - Arabic
  kuArab,

  /// Chinese (Simplified China)
  zhCn,

  /// Chinese (Traditional Hong Kong)
  zhHk,

  /// Chinese (Traditional Taiwan)
  zhTw,

  /// Croatian
  hrHr,

  /// Czech
  csCz,

  /// Danish
  daDk,

  /// Dari - Arabic (Afghanistan)
  prsArabAf,

  /// Dutch
  nlNl,

  /// English (British)
  enGb,

  /// Estonian
  etEe,

  /// Farsi (Iran)
  faIr,

  /// Filipino
  filPh,

  /// Finnish
  fiFi,

  /// French
  frFr,

  /// French (Canada)
  frCa,

  /// Galician
  glEs,

  /// Georgian
  kaGe,

  /// German
  deDe,

  /// Greek
  elGr,

  /// Gujarati (India)
  guIn,

  /// Hausa - Latin (Nigeria)
  haLatnNg,

  /// Hebrew
  heIl,

  /// Hindi
  hiIn,

  /// Hungarian
  huHu,

  /// Icelandic
  isIs,

  /// Igbo - Latin (Nigera)
  igLatnNg,

  /// Indonesian (Bahasa)
  idId,

  /// Irish
  gaIe,

  /// IsiXhosa
  xh,

  /// IsiZulu (South Africa)
  zuZa,

  /// Italian
  itIt,

  /// Japanese
  jaJp,

  /// Kannada (India)
  knIn,

  /// Kazakh
  kkKz,

  /// Khmer (Cambodia)
  kmKh,

  /// K'iche' - Latin (Guatemala)
  qucLatnGt,

  /// Kinyarwanda (Rwanda)
  rwRw,

  /// KiSwahili
  sw,

  /// Konkani (India)
  kokIn,

  /// Korean
  koKr,

  /// Kyrgyz - Cyrillic
  kyCyrlKg,

  /// Latvian
  lvLv,

  /// Lithuanian
  ltLt,

  /// Luxembourgish
  lbLu,

  /// Macedonian
  mkMk,

  /// Malay (Bahasa)
  msMy,

  /// Malayalam (India)
  mlIn,

  /// Maltese  (Malta)
  mtMt,

  /// Maori - Latin (New Zealand)
  miLatnNz,

  /// Marathi (India)
  mrIn,

  /// Mongolian - Cyrillic
  mnCyrlMn,

  /// Nepali (Nepal)
  neNp,

  /// Norwegian (Bokma?l)
  nbNo,

  /// Norwegian (Nynorsk)
  nnNo,

  /// Odia (India)
  orIn,

  /// Polish
  plPl,

  /// Portuguese (Brazil)
  ptBr,

  /// Portuguese (Portugal)
  ptPt,

  /// Punjabi - Gurmukhi
  paGuru,

  /// Punjabi - Arabic
  paArab,

  /// Quechua - Latin (Peru)
  quLatnPe,

  /// Romanian
  roRo,

  /// Russian
  ruRu,

  /// Scottish Gaelic - Latin
  gdLatnGb,

  /// Serbian - Cyrillic (Bosnia)
  srCyrlBa,

  /// Serbian - Cyrillic (Serbia)
  srCyrlRs,

  /// Serbian - Latin (Serbia)
  srLatnRs,

  /// Sesotho Sa Leboa (South Africa)
  nsoZa,

  /// Setswana
  tn,

  /// Sindhi - Arabic
  sdArab,

  /// Sinhala (Sri Lanka)
  siLk,

  /// Slovak
  skSk,

  /// Slovenian
  slSi,

  /// Spanish (Mexico)
  esMx,

  /// Spanish (Spain)
  esEs,

  /// Swedish
  svSe,

  /// Tajik - Cyrillic
  tgCyrlTj,

  /// Tamil
  ta,

  /// Tatar - Cyrillic (Russia)
  ttCyrlRu,

  /// Telugu (India)
  teIn,

  /// Thai
  thTh,

  /// Tigrinya (Ethiopia)
  tiEt,

  /// Turkish
  trTr,

  /// Turkmen - Latin
  tkLatnTm,

  /// Ukrainian
  ukUa,

  /// Urdu
  ur,

  /// Uyghur - Arabic
  ugArab,

  /// Uzbek - Cyrillic
  uzCyrlUz,

  /// Uzbek - Latin
  uzLatnUz,

  /// Valencian (Spain)
  catEs,

  /// Vietnamese
  viVn,

  /// Welsh
  cyGb,

  /// Wolof - Latin
  woLatn,

  /// Yoruba - Latin
  yoLatn
}
